@@ -1,7 +1,7 @@
 
 from seti_python.class_read import ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions, ResponseReadWallet, ResponseReadWalletsTransactions
 from seti_python.wallet_class import ResponseCreateWallet
-from seti_python.class_tools import BasicResponse, ResponseCreateTransaction
+from seti_python.class_tools import BasicResponse, CompleteBasicaResponse, ResponseCreateTransaction
 from seti_python.payment_class import ResponseCreatePayment
 from typing import List
 import execjs
@@ -134,7 +134,7 @@ class Seti():
         }
         VALIDATE_WALLET_URL = "validate-wallet"
         encode_data = self.sign_data(data_validate_wallet)
-        return BasicResponse(self.send_request(data_validate_wallet,encode_data,VALIDATE_WALLET_URL))
+        return CompleteBasicaResponse(self.send_request(data_validate_wallet,encode_data,VALIDATE_WALLET_URL))
     
     def read_wallet_data(self,secret:str):
         self.is_error = False
