@@ -147,11 +147,11 @@ class ResponseReadTransactions(BasicResponse):
 # Read Wallet
 
 class WalletData:
-    balance:str
+    balance:int
     currency:str
-    locked:str
-    timestamp:str
-    wallet_id:int
+    locked:bool
+    timestamp:dict
+    wallet_id:str
     def  __init__(self,data):
         self.balance=data["balance"]
         self.currency=data["currency"]
